pub struct SetDelegate {}Trait Implementations
Sourceimpl ArrangeAccounts for SetDelegate
impl ArrangeAccounts for SetDelegate
type ArrangedAccounts = SetDelegateInstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for SetDelegate
impl BorshDeserialize for SetDelegate
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for SetDelegate
impl CarbonDeserialize for SetDelegate
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for SetDelegate
impl Clone for SetDelegate
Sourcefn clone(&self) -> SetDelegate
fn clone(&self) -> SetDelegate
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetDelegate
impl Debug for SetDelegate
Sourceimpl<'de> Deserialize<'de> for SetDelegate
impl<'de> Deserialize<'de> for SetDelegate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for SetDelegate
impl Hash for SetDelegate
Sourceimpl PartialEq for SetDelegate
impl PartialEq for SetDelegate
Sourceimpl Serialize for SetDelegate
impl Serialize for SetDelegate
impl Eq for SetDelegate
impl StructuralPartialEq for SetDelegate